#
# Cookbook:: cdo
# Recipe:: default
#
# Copyright:: 2018, The Dark Sky Company, LLC, All Rights Reserved.

%w(
  build-essential
  git
).each do |r|
  include_recipe r
end

# libcurl for netCDF-4
# libtool for hdf5
# fortran for ecCodes
%w(
  cmake
  libcurl4-gnutls-dev
  libtool
  libtool-bin
  gfortran
).each do |pkg|
  package pkg
end

# Install zlib
ark 'zlib' do
  url node['cdo']['zlib']['url']
  version node['cdo']['zlib']['version']
  action :install_with_make
end

# Install hdf5
ark 'hdf5' do
  url node['cdo']['hdf5']['url']
  extension 'tar.gz'
  autoconf_opts %w(--prefix=/usr/local)
  version node['cdo']['hdf5']['version']
  action :install_with_make
end

# Install netCDF
ark 'netcdf' do
  url node['cdo']['netcdf']['url']
  version node['cdo']['netcdf']['version']
  action :install_with_make
end

# Install JasPer
jasper_path = node['cdo']['jasper']['path']

src_filepath = "#{file_cache_path}/#{::File.basename node['cdo']['jasper']['url']}"

remote_file src_filepath do
  source node['cdo']['jasper']['url']
  backup false
end

execute 'unarchive_jasper_archive' do
  command "tar -zxf #{src_filepath}"
  cwd     ::File.dirname jasper_path
  creates jasper_path
end

directory "#{jasper_path}/release"

execute 'make_jasper' do
  command     'cmake -G "Unix Makefiles" -DCMAKE_BUILD_TYPE=Release .. && make && make install'
  cwd         "#{jasper_path}/release"
  creates     "/usr/local/lib/libjasper.so.#{node['cdo']['jasper']['version']}"
end

# Install ecCodes
eccodes_path = node['cdo']['eccodes']['path']

src_filepath = "#{file_cache_path}/#{::File.basename node['cdo']['eccodes']['url']}"

remote_file src_filepath do
  source node['cdo']['eccodes']['url']
  backup false
end

execute 'unarchive_eccodes_archive' do
  command "tar -zxf #{src_filepath}"
  cwd     ::File.dirname jasper_path
  creates eccodes_path
end

directory "#{eccodes_path}/build"

execute 'make_eccodes' do
  command     'cmake .. && make && make install'
  cwd         "#{eccodes_path}/build"
  creates     "/usr/local/lib/libeccodes.so.#{node['cdo']['eccodes']['version']}"
end

# Ensure shared libraries are properly linked
execute 'ldconfig'

# Install CDO
ark 'cdo' do
  url node['cdo']['url']
  version node['cdo']['version']
  autoconf_opts %w(--with-netcdf=yes --with-hdf5=yes --with-eccodes=yes)
  action :install_with_make
end
